pub struct RealAssetsReport {
pub total_assets: U128,
pub per_market: Vec<(MarketId, U128)>,
pub refreshed_at: U64,
}Expand description
Report of real (live) total assets broken down by market, used for AUM refresh.
Fields
total_assets: U128per_market: Vec<(MarketId, U128)>refreshed_at: U64Block timestamp in nanoseconds when this report was generated.