pub struct VaultConfiguration {Show 14 fields
pub owner: AccountId,
pub curator: AccountId,
pub sentinel: AccountId,
pub underlying_token: FungibleAsset<BorrowAsset>,
pub initial_timelock_ns: U64,
pub fees: Fees<Wad>,
pub skim_recipient: AccountId,
pub name: String,
pub symbol: String,
pub decimals: NonZeroU8,
pub restrictions: Option<Restrictions>,
pub refresh_cooldown_ns: Option<U64>,
pub idle_resync_cooldown_ns: Option<U64>,
pub withdrawal_cooldown_ns: Option<U64>,
}Expand description
Configuration for the setup of a metavault.
Fields
owner: AccountIdThe account that owns this vault.
curator: AccountIdThe account that can submit allocation plans. See [AllocationMode].
sentinel: AccountIdThe emergency role that can cancel withdrawals and trigger deallocations.
underlying_token: FungibleAsset<BorrowAsset>The underlying asset for this vault.
initial_timelock_ns: U64The initial timelock for this vault used for modifying the configuration.
fees: Fees<Wad>Fee configuration for performance and management fees as well as their recipients.
skim_recipient: AccountIdThe skim account that can unorphan any assets erroneously sent to this vault.
name: StringThe name of the share token.
symbol: StringThe symbol of the share token.
decimals: NonZeroU8The number of decimals for the share token, usually would be the same as the underlying asset.
restrictions: Option<Restrictions>Restrictions for this vault.
refresh_cooldown_ns: Option<U64>Optional cooldown (ns) between refresh_markets calls; defaults to 30 seconds when None.
idle_resync_cooldown_ns: Option<U64>Optional cooldown (ns) between idle_resync calls; defaults to 120 seconds when None.
withdrawal_cooldown_ns: Option<U64>Optional cooldown (ns) before a withdrawal can be executed; defaults to 1 hour when None.